@@ -33,7 +33,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use warnings;
 use Carp;
@@ -50,6 +50,17 @@ our %field_conf = (
       $val;
     }
   },
+  def => {
+    type => 'SINGLE',
+    process => sub {
+      my $val = shift;
+      $val =~ s/"(.*)".*/$1/g;
+      $val;
+    }
+  },
+  comment => {
+    type => 'SINGLE',
+  },
   is_obsolete => {
     type => 'SINGLE',
     process => sub {
