@@ -2,7 +2,7 @@ package PomBase::Chobo::OntologyTerm;
 
 =head1 NAME
 
-PomBase::Chobo::OntologyTerm - Simple class for accessing term data
+PomBase::Chobo::OntologyTerm - Code for holding term data read from an OBO file
 
 =head1 SYNOPSIS
 
@@ -35,7 +35,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use Mouse;
 use Carp;
@@ -50,7 +50,9 @@ has id => (is => 'ro', isa => 'Int', required => 1);
 has cvterm_id => (is => 'ro', isa => 'Int', required => 0);
 has cv_id => (is => 'ro', isa => 'Int', required => 0);
 has name => (is => 'ro', isa => 'Str');
+has def => (is => 'ro', isa => 'Str');
 has namespace => (is => 'ro', isa => 'Str');
+has comment => (is => 'ro', isa => 'Str');
 has alt_id => (is => 'ro', isa => 'ArrayRef');
 has is_relationshiptype => (is => 'ro', isa => 'Bool');
 has source_file => (is => 'ro', isa => 'Str', required => 1);
